/*
 * File: SuchADrag.java
 * ================================================================
 * A program that shows off dragging objects around.
 */
import acm.program.*;
import acm.graphics.*;
import java.awt.*;
import java.awt.event.*;

public class SuchADrag extends GraphicsProgram {
	/* The size of the objects. */
	private static final double OBJECT_SIZE = 50;
	
	/* Sets up the world and initializes mouse listeners. */
	public void run() {
		addObjects();
		addMouseListeners();
	}
	
	/**
	 * Creates a GRect and GOval and adds them to the world
	 */
	private void addObjects() {
		/* Add a blue oval. */
		GOval oval = new GOval(0, 0, OBJECT_SIZE, OBJECT_SIZE);
		oval.setFilled(true);
		oval.setColor(Color.BLUE);
		add(oval);
		
		/* Add a blue rectangle. */
		GRect rect = new GRect(getWidth() - OBJECT_SIZE, getHeight() - OBJECT_SIZE,
		                       OBJECT_SIZE, OBJECT_SIZE);
		rect.setFilled(true);
		rect.setColor(Color.BLUE);
		add(rect);
	}
	
	/* The object currently being dragged, or null if nothing is being dragged. */
	private GObject draggedObject;
	
	/* The X and Y coordinate of the mouse at the time of the last event. */
	private double lastX, lastY;
	
	public void mousePressed(MouseEvent e) {
		/* See what we clicked on. */
		GObject hit = getElementAt(e.getX(), e.getY());
		
		/* If we clicked something, start dragging it. */
		if (hit != null) {
			hit.setColor(Color.RED);
			draggedObject = hit;
			
			lastX = e.getX();
			lastY = e.getY();
		}
	}
	
	public void mouseDragged(MouseEvent e) {
		/* If something was dragged, move it appropriately. */
		if (draggedObject != null) {
			/* Calculate the delta from the previous event. */
			double dx = e.getX() - lastX;
			double dy = e.getY() - lastY;
			
			/* Move the object by that amount. */
			draggedObject.move(dx, dy);
			
			lastX = e.getX();
			lastY = e.getY();
		}
	}
	
	public void mouseReleased(MouseEvent e) {
		/* If we were dragging something, deselect it. */
		if (draggedObject != null) {
			draggedObject.setColor(Color.BLUE);
			draggedObject = null;
		}
	}
}
